pub struct AesWriter<E: BlockEncryptor, W: Write> {
pub enc: CbcEncryptor<E, EncPadding<PkcsPadding>>,
/* private fields */
}Fields
enc: CbcEncryptor<E, EncPadding<PkcsPadding>>Encryptor to encrypt data with
Implementations
Sourceimpl<E: BlockEncryptor, W: Write> AesWriter<E, W>
If you don’t want the header you can use this initializer
impl<E: BlockEncryptor, W: Write> AesWriter<E, W>
If you don’t want the header you can use this initializer
pub fn new(iv: Vec<u8>, writer: W, enc: E) -> Result<AesWriter<E, W>>
Sourcepub fn new_with_infos(
iv: Vec<u8>,
infos: CryptoInfo,
writer: W,
enc: E,
) -> Result<AesWriter<E, W>>
pub fn new_with_infos( iv: Vec<u8>, infos: CryptoInfo, writer: W, enc: E, ) -> Result<AesWriter<E, W>>
Initializer that will store info in the file. You muse use the AesReader::new_with_info to decrypt this kind of file
pub fn write_direct(&mut self, buf: &[u8]) -> Result<usize>